/**
 * The CpuArchitecture for Fargate Runtime Platform.
 *
 * @stability stable
 */
export declare class CpuArchitecture {
    readonly _cpuArchitecture: string;
    /**
     * ARM64.
     *
     * @stability stable
     */
    static readonly ARM64: CpuArchitecture;
    /**
     * X86_64.
     *
     * @stability stable
     */
    static readonly X86_64: CpuArchitecture;
    /**
     * Other cpu architecture.
     *
     * @param cpuArchitecture cpu architecture.
     * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ecs-taskdefinition-runtimeplatform.html#cfn-ecs-taskdefinition-runtimeplatform-cpuarchitecture for all available cpu architecture.
     * @stability stable
     */
    static of(cpuArchitecture: string): CpuArchitecture;
    /**
     *
     * @param _cpuArchitecture The CPU architecture.
     */
    private constructor();
}
/**
 * The operating system for Fargate Runtime Platform.
 *
 * @stability stable
 */
export declare class OperatingSystemFamily {
    readonly _operatingSystemFamily: string;
    /**
     * LINUX.
     *
     * @stability stable
     */
    static readonly LINUX: OperatingSystemFamily;
    /**
     * WINDOWS_SERVER_2004_CORE.
     *
     * @stability stable
     */
    static readonly WINDOWS_SERVER_2004_CORE: OperatingSystemFamily;
    /**
     * WINDOWS_SERVER_2016_FULL.
     *
     * @stability stable
     */
    static readonly WINDOWS_SERVER_2016_FULL: OperatingSystemFamily;
    /**
     * WINDOWS_SERVER_2019_CORE.
     *
     * @stability stable
     */
    static readonly WINDOWS_SERVER_2019_CORE: OperatingSystemFamily;
    /**
     * WINDOWS_SERVER_2019_FULL.
     *
     * @stability stable
     */
    static readonly WINDOWS_SERVER_2019_FULL: OperatingSystemFamily;
    /**
     * WINDOWS_SERVER_2022_CORE.
     *
     * @stability stable
     */
    static readonly WINDOWS_SERVER_2022_CORE: OperatingSystemFamily;
    /**
     * WINDOWS_SERVER_2022_FULL.
     *
     * @stability stable
     */
    static readonly WINDOWS_SERVER_2022_FULL: OperatingSystemFamily;
    /**
     * WINDOWS_SERVER_20H2_CORE.
     *
     * @stability stable
     */
    static readonly WINDOWS_SERVER_20H2_CORE: OperatingSystemFamily;
    /**
     * Other operating system family.
     *
     * @param family operating system family.
     * @see https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ecs-taskdefinition-runtimeplatform.html#cfn-ecs-taskdefinition-runtimeplatform-operatingsystemfamily for all available operating system family.
     * @stability stable
     */
    static of(family: string): OperatingSystemFamily;
    /**
     *
     * @param _operatingSystemFamily The operating system family.
     */
    private constructor();
}
/**
 * The interface for Runtime Platform.
 *
 * @stability stable
 */
export interface RuntimePlatform {
    /**
     * The CpuArchitecture for Fargate Runtime Platform.
     *
     * @default - Undefined.
     * @stability stable
     */
    readonly cpuArchitecture?: CpuArchitecture;
    /**
     * The operating system for Fargate Runtime Platform.
     *
     * @default - Undefined.
     * @stability stable
     */
    readonly operatingSystemFamily?: OperatingSystemFamily;
}
